@@ -69,7 +69,7 @@ protected:
 
     void set_pattern_(const std::string &pattern) override
     {
-        set_formatter_(spdlog::make_unique<spdlog::pattern_formatter>(pattern));
+        set_formatter_(details::make_unique<spdlog::pattern_formatter>(pattern));
     }
 
     void set_formatter_(std::unique_ptr<spdlog::formatter> sink_formatter) override
